pub struct Editor {
pub lines: Vec<String>,
pub row: usize,
pub col: usize,
pub top: usize,
pub preview: Preview,
pub dirty: bool,
pub message: Option<String>,
/* private fields */
}Fields
lines: Vec<String>row: usizecol: usizeColumn as a character index into the current line.
top: usizeFirst visible row; the UI adjusts it to keep the cursor in view.
preview: Previewdirty: boolmessage: Option<String>Implementations