pub fn calibration_text(calibration: &Calibration, page: &str) -> StringExpand description
The calibration as plain text, for under the report.
pub fn calibration_text(calibration: &Calibration, page: &str) -> StringThe calibration as plain text, for under the report.