pub struct Latency {
pub threads: usize,
pub on_time: usize,
pub early: usize,
pub late: usize,
pub missed: usize,
pub false_alarms: usize,
pub mean: Option<f64>,
pub cases: Vec<ThreadLatency>,
}Expand description
How early or late a noul notices, over the conversations labelled per turn.
Fields
threads: usizeon_time: usizeearly: usizelate: usizemissed: usizefalse_alarms: usizemean: Option<f64>Mean latency over the threads that expected a yes and got one; None when none did.
cases: Vec<ThreadLatency>Trait Implementations
impl StructuralPartialEq for Latency