pub struct ReportUsage {
pub input_tokens: u64,
pub output_tokens: u64,
pub estimated: bool,
pub cost: Option<Cost>,
}Expand description
The tokens the run spent, counted when the API counted them and estimated when it did not.
Fields
input_tokens: u64output_tokens: u64estimated: boolcost: Option<Cost>Trait Implementations
Sourceimpl Clone for ReportUsage
impl Clone for ReportUsage
Sourceimpl Debug for ReportUsage
impl Debug for ReportUsage
Sourceimpl PartialEq for ReportUsage
impl PartialEq for ReportUsage
impl StructuralPartialEq for ReportUsage