value

Function value 

pub fn value(text: &str) -> Value
Text becomes a JSON value when it is written as one (an object, an array or a quoted string); anything else is sent as the plain string it is.